[![Github Release](https://img.shields.io/github/v/release/lishuangshuang0616/DNBC4tools)](https://github.com/lishuangshuang0616/DNBC4tools/releases)
[![PyPI](https://img.shields.io/pypi/v/dnbc4tools)](https://pypi.org/project/DNBC4tools)
[![Docker Pulls](https://img.shields.io/docker/pulls/lishuangshuang3/dnbc4tools)](https://hub.docker.com/r/lishuangshuang3/dnbc4tools)
[![docs](https://img.shields.io/static/v1?label=docs&message=dnbc4tools&color=blue)](https://dnbc4tools.readthedocs.io)
[![downloads](https://static.pepy.tech/personalized-badge/dnbc4tools?period=total&units=international_system&left_color=grey&right_color=blue&left_text=downloads)](https://pepy.tech/project/dnbc4tools)


# DNBelab_C_Series_HT_scRNA-analysis-software

## Introduction

An open source and flexible pipeline to analyze high-throughput DNBelab C Series<sup>TM</sup> single-cell RNA datasets. 

**Hardware/Software requirements** 

- x86-64 compatible processors.
- require at least 50GB of RAM and 4 CPU. 
- centos 7.x 64-bit operating system (Linux kernel 3.10.0, compatible with higher software and hardware configuration). 

**Workflow**
 
 <img src="./doc/pipeline.jpg" width="70%">

## Start

- [**installation** ](./doc/installation.md)

- [**quick start** ](./doc/quickstart.md)

- [**Documentation** ](./doc/detail.md)

## Support

- Please use github issue tracker for questions. [**issues**](https://github.com/MGI-tech-bioinformatics/DNBelab_C_Series_HT_scRNA-analysis-software/issues)
- Read the Docs. [**docs**](https://dnbc4tools.readthedocs.io)
